/***************************************************************************
						guimain.cpp    -  description
							-------------------
	begin                : march 22th, 2004
	copyright            : (C) 2004-2006 by Duong-Khang NGUYEN
	email                : neoneurone @ users sourceforge net

	$Id: guimain.cpp 175 2007-02-22 20:14:42Z neoneurone $
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   any later version.                                                    *
 *                                                                         *
 ***************************************************************************/

#include "guimain.h"


   /*=====================================================================*/
GUIMain::GUIMain():
_pctr( NULL ),
_iX( 0 ),
_iY( 0 ),
_uiWidth( 0 ),
_uiHeight( 0 ),
_ubAttribute( 0 )
{
}


   /*=====================================================================*/
GUIMain::~GUIMain()
{
}




































